@@ -7,6 +7,7 @@ import string
 import os
 import inspect
 import datetime
+from datetime import datetime
 
 from qds_ops.tparty.knife import Knife
 from qds_ops.utils.deploy_utils import DeployUtils
@@ -234,14 +235,15 @@ class Tier(object):
         key_name = rows["value"]
         as_group_name = self.as_name(args.environment)
         logging.info("%s autoscale group name: %s" % (self.tier, as_group_name))
-        as_lc_name = "%s_%s_launch_group_%s" % (self.tier, args.environment, str(datetime.datetime.now().date()))
+        as_lc_name = "%s_%s_launch_group_%s" % (self.tier, args.environment, datetime.now().strftime("%Y-%m-%d-%H-%M"))
         logging.info("%s autoscale launch configuration: %s" % (self.tier, as_lc_name))
 
         # set the udf. udf is encoded by boto
         base_path = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
         filein = open(base_path + "/../scripts/udf.sh")
         src = string.Template(filein.read())
-        resolved_runlist = self.run_list % (self.tier, self.worker)
+        cpre = DeployUtils.get_cbook_prefix(args.environment)
+        resolved_runlist = self.run_list % (cpre, self.tier, self.worker)
         d = {'runlist': resolved_runlist, 'environment': args.environment}
         user_data = src.safe_substitute(d)
 
