@@ -16,7 +16,7 @@ class Web(Tier):
     def __init__(self):
         tier = "web"
         modules = ["hive_scripts", "hadoop", "hadoop2", "hustler", "hive", "hive13", "hive2", "sqoop", "pig", "tapp2", "cloudman", "cluster_proxy"]
-        run_list = '{"run_list":["recipe[webslave]"], "qubole_tier":"%s", "worker_name": "%s"}'
+        run_list = '{"run_list":["recipe[%swebslave]"], "qubole_tier":"%s", "worker_name": "%s"}'
         worker = "qpal_worker"
         ami = "ami-0edbb766"
         region = "us-east-1"
