@@ -11,6 +11,7 @@ end
 optparser.parse!
 
 out_path = ARGV[0]
+cloud = ARGV[1]
 
 class Cbook
   attr_accessor :version
@@ -20,28 +21,29 @@ class Cbook
   end
 
   def maintainer(a)
-  end  
+  end
   def maintainer_email(a)
-  end  
+  end
   def license(a)
-  end  
+  end
   def description(a)
-  end  
+  end
   def long_description(a)
-  end  
+  end
   def version(a = nil)
     @version = a if !a.nil?
     @version
-  end  
+  end
   def depends(a)
-  end  
+  end
 end
 
 
 cbook_mdata = Cbook.new
 f = "#{out_path}/chef-repo/cookbooks/webslave/metadata.rb"
-cbook_mdata.instance_eval(IO.read(f)) 
+f = "#{out_path}/chef-repo/cookbooks/#{cloud}_webslave/metadata.rb" if cloud != "aws"
+
+cbook_mdata.instance_eval(IO.read(f))
 
 puts cbook_mdata.version
-exit(0)
-
+exit(0)
\ No newline at end of file
