@@ -12,6 +12,16 @@ from qds_ops.tparty.knife import Knife
 
 
 class DeployUtils:
+    
+    @staticmethod
+    def get_cbook_prefix(env):
+        knife = Knife()
+        cpre = ""
+        creds = knife.get_credentials(env)
+        if creds.has_key("cloud") and creds["cloud"].strip() != "aws":
+            cpre = creds["cloud"] + '_'
+        return cpre
+
     @staticmethod
     def wait_till_node_registers(env, tier, master_id):
         search_string = "name:%s" % master_id
@@ -49,7 +59,8 @@ class DeployUtils:
     @staticmethod
     def run_common_stuff(env, tier, pemfile):#${env_str} $host $password $username $database $lb_name ${pemfile} ${a}):
         logging.info("Running common stuff recipe on all nodes because -c argument is specified.")
-        run_list = '{"run_list":["recipe[webslave::common_stuff]"]}'
+        cpre = DeployUtils.get_cbook_prefix(env)
+        run_list = '{"run_list":["recipe[%swebslave::common_stuff]"]}' % cpre
         chef_command = "echo '%s' > /tmp/runlist; sudo chef-client -j /tmp/runlist -E %s" % (run_list, env)
         retcode = DeployUtils.run_chef_command(chef_command, env, tier, pemfile, "")
         logging.info("-------Done with running the common stuff recipe--------")
@@ -60,7 +71,8 @@ class DeployUtils:
                                     env):#${env_str} $host $password $username $database $lb_name ${pemfile} ${a}):
         chef_command = "sudo chef-client -j /etc/chef/first-boot.json -E %s" % (env)
         if module != "all":
-            run_list = '{"run_list":["recipe[webslave::deploy_%s]"]}' % (module)
+            cpre = DeployUtils.get_cbook_prefix(env)
+            run_list = '{"run_list":["recipe[%swebslave::deploy_%s]"]}' % (cpre,module)
             chef_command = "echo '%s' > /tmp/runlist; sudo chef-client -j /tmp/runlist" % (run_list)
         return chef_command
 
@@ -95,4 +107,4 @@ class DeployUtils:
         else:
             p = Popen(["knife", "ssh", slave_selector, chef_command, "-x", "ec2-user", "-i", pemfile, "-a",
                        "ec2.public_hostname", "--no-host-key-verify"])
-            retcode = p.wait()
\ No newline at end of file
+            retcode = p.wait()
